==> cmios9-2.0.tar.gz: cmios9-2.0/cmios9_io.h <==
#ifndef __CMIOS9_IO_H
#define __CMIOS9_IO_H
/*
* Copyright (C) 2001, 2002, 2003, 2004  K. M. Indlekofer
*
* M.Indlekofer@fz-juelich.de
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



#ifdef WIN32
/* e.g. VC++ */

#include "winlib_cmios9.h"

#else /* !WIN32 */
/* e.g. UNIX-like systems or cygwin */

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <limits.h>
#include <unistd.h>
#include <strings.h>
#include <string.h>
#include <ctype.h>
#include <time.h>

#endif /* !WIN32 */



/* might need improved lseek and off_t to handle >=2GB */
#ifndef LSEEK
#define LSEEK lseek
#endif /* !LSEEK */
#ifndef OFF_T
#define OFF_T off_t
#endif /* !OFF_T */



/* O_BINARY important for Windows-based systems (esp. cygwin or VC++) */
#ifndef O_BINARY
#define O_BINARY 0
#endif /* !O_BINARY */



/* basic I/O */
/* device */
extern int readonly;

/* device I/O granularity */
#ifndef DEV_BLOCKSIZE
#define DEV_BLOCKSIZE 2048 /* XXX needed for CDROM drives, OK with others */
#endif
/* XXX if device size not integer multiples of DEV_BLOCKSIZE, */
/* we might get access-problems for data in last incomplete DEV_BLOCKSIZE chunk!!! */



extern int readblock(int devdes,u_int blknr,void *buf,u_int bufsiz,u_int startsec,u_int totsize,u_int blksiz);
extern int writeblock(int devdes,u_int blknr,void *buf,u_int bufsiz,u_int startsec,u_int totsize,u_int blksiz);
extern int opendevice(char *devpath);



#endif /* !__CMIOS9_IO_H */

==> cmios9-2.1.tar.gz: cmios9-2.1/cmios9_io.h <==
#ifndef __CMIOS9_IO_H
#define __CMIOS9_IO_H
/*
* Copyright (C) 2001, 2002, 2003, 2004, 2005  K. M. Indlekofer
*
* M.Indlekofer@fz-juelich.de
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/



#ifdef WIN32
/* e.g. VC++ */

#include "winlib_cmios9.h"

#else /* !WIN32 */
/* e.g. UNIX-like systems or cygwin */

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <limits.h>
#include <unistd.h>
#include <strings.h>
#include <string.h>
#include <ctype.h>
#include <time.h>

#endif /* !WIN32 */



/* might need improved lseek and off_t to handle >=2GB */
#ifndef LSEEK
#define LSEEK lseek
#endif /* !LSEEK */
#ifndef OFF_T
#define OFF_T off_t
#endif /* !OFF_T */



/* O_BINARY important for Windows-based systems (esp. cygwin or VC++) */
#ifndef O_BINARY
#define O_BINARY 0
#endif /* !O_BINARY */



/* basic I/O */
/* device */
extern int readonly;

/* default device I/O granularity */
#ifndef DEV_BLOCKSIZE
#define DEV_BLOCKSIZE 2048 /* XXX needed for CDROM drives, OK with others */
#endif
/* XXX if device size not integer multiples of DEV_BLOCKSIZE, */
/* we might get access-problems for data in last incomplete DEV_BLOCKSIZE chunk!!! */



extern int readblock(int devdes,u_int blknr,void *buf,u_int bufsiz,u_int startsec,u_int totsize,u_int blksiz);
extern int writeblock(int devdes,u_int blknr,void *buf,u_int bufsiz,u_int startsec,u_int totsize,u_int blksiz);
extern int opendevice(char *devpath);



#endif /* !__CMIOS9_IO_H */
